diff --git a/IPython/core/magics/namespace.py b/IPython/core/magics/namespace.py
index a3b3be5..c02b387 100644
--- a/IPython/core/magics/namespace.py
+++ b/IPython/core/magics/namespace.py
@@ -497,7 +497,7 @@ class NamespaceMagics(Magics):
 
         See Also
         --------
-        magic_reset_selective : invoked as ``%reset_selective``
+        reset_selective : invoked as ``%reset_selective``
 
         Examples
         --------
@@ -612,7 +612,7 @@ class NamespaceMagics(Magics):
 
         See Also
         --------
-        magic_reset : invoked as ``%reset``
+        reset : invoked as ``%reset``
 
         Examples
         --------
diff --git a/IPython/core/magics/basic.py b/IPython/core/magics/basic.py
index dcec6be..cf86ac8 100644
--- a/IPython/core/magics/basic.py
+++ b/IPython/core/magics/basic.py
@@ -305,7 +305,13 @@ Currently the magic system has the following functions:""",
 
     @line_magic
     def profile(self, parameter_s=''):
-        """Print your currently active IPython profile."""
+        """Print your currently active IPython profile.
+       
+        See Also
+        --------
+        prun : run code using the Python profiler
+               (:meth:`~IPython.core.magics.execution.ExecutionMagics.prun`)
+        """
         from IPython.core.application import BaseIPythonApplication
         if BaseIPythonApplication.initialized():
             print(BaseIPythonApplication.instance().profile)